This package has been renamed. Please download the latest version, now called `django-awesome-tools`.

- Pypi: https://pypi.org/project/django-awesome-tools/
- Github: https://github.com/cayo-rodrigues/django-awesome-tools